local	AddonName, Addon	= ...
local	Version			= GetAddOnMetadata ( AddonName , "Version" );
local	Title			= "Hide Gryphons"
local	EventFrame		= CreateFrame( "Frame" , Title , UIParent );	
	-------------------------------------------------------------------------------------------
        -- ADDON VARIABLES ---------------------------------------------------------------------
        -------------------------------------------------------------------------------------------
		local	Options			= Addon.Options
	-------------------------------------------------------------------------------------------
        -- ADDON LOCAL FUNCTIONS ------------------------------------------------------------------------
        -------------------------------------------------------------------------------------------
	local function HideGryphons()

		if (select(4, GetBuildInfo()) < 20000) 
		then	-- for WOW Classic
			MainMenuBarLeftEndCap:Hide();
			MainMenuBarRightEndCap:Hide();
		else	-- for Current WOW
			MainMenuBarArtFrame.LeftEndCap:Hide();
			MainMenuBarArtFrame.RightEndCap:Hide();
		end	
	end

	local function ShowGryphons()

		if (select(4, GetBuildInfo()) < 20000) 
		then	-- for WOW Classic
			MainMenuBarLeftEndCap:Show();
			MainMenuBarRightEndCap:Show();
		else	-- for Current WOW
			MainMenuBarArtFrame.LeftEndCap:Show();
			MainMenuBarArtFrame.RightEndCap:Show();
		end	
	end
	-------------------------------------------------------------------------------------------
	-- EVENT ADDON_LOADED ----------------------------------------------------------------
	-------------------------------------------------------------------------------------------
	function EventFrame : ADDON_LOADED ()

		-------------------------------------------------------------------------------------------
		-- Addon Database -------------------------------------------------------------------------
		-------------------------------------------------------------------------------------------
		_G.SettingsDB = _G.SettingsDB or {};
	
		local 	DefaultDB = {
					 HideGryphons	= { Enbled = true };			
			};

		for k,v in pairs(DefaultDB) do
			if (not _G.SettingsDB[k]) then
				_G.SettingsDB[k] = v;
			end
		end

		-------------------------------------------------------------------------------------------
		-- Addon Option ---------------------------------------------------------------------
		-------------------------------------------------------------------------------------------

	
		Addon.Option = CreateFrame( "Frame", Title .. " Option" , UIParent);
		Addon.Option.name	= AddonName;

		Addon.Option.Title	= Addon.Option:CreateFontString("$parentTitle", "ARTWORK", "GameFontNormalLarge")
		Addon.Option.Title	: SetPoint ( "TOPLEFT" , Addon.Option,  "TOPLEFT" , 15 , -15 )
		Addon.Option.Title	: SetText ( Title .. " Plugin Option" .. " |cff0066ff" .. Version .. "|r" )

		Addon.Option.Note	= Addon.Option:CreateFontString("$parentNote", "ARTWORK", "GameFontHighlight")
		Addon.Option.Note	: SetPoint ( "TOPLEFT" , Addon.Option.Title,  "BOTTOMLEFT" , 0 , -10 )
		Addon.Option.Note	: SetText ( "Simple Hide Gryphons from the Actionbars" )

		Addon.Option.CheckButton	= CreateFrame('CheckButton', Title .. "CheckButton", Addon.Option, 'InterfaceOptionsCheckButtonTemplate')
		Addon.Option.CheckButton	: SetPoint ( "TOPLEFT" , Addon.Option.Note,  "BOTTOMLEFT" , 0 , -10 )
		Addon.Option.CheckButton.Text	= _G[Title .. "CheckButtonText"]
		Addon.Option.CheckButton.Text	: SetText("HideGryphons")

		Addon.Option.CheckButton : SetScript("OnClick", function(self,event,arg1)
			if self:GetChecked() then
				SettingsDB.HideGryphons.Enbled = true
				HideGryphons()
			else
				SettingsDB.HideGryphons.Enbled = false
				ShowGryphons()
			end
		end)
	
		Addon.Option.Copyright	= Addon.Option:CreateFontString("$parentCopyright", "ARTWORK", "GameFontHighlight")
		Addon.Option.Copyright	: SetPoint ( "BOTTOMRIGHT" , Addon.Option,  "BOTTOMRIGHT" , -10 , 10 )
		Addon.Option.Copyright	: SetText ( "|cff3399ffCoded by |cffff0000Devil|r |cffFFFFFF(C)|r" )



		Addon.Option.okay = function (self) end;       -- When the player clicks Okay, run this function.

		Addon.Option.cancel = function (self) end;        -- When the player clicks cancel, run this function.

		Addon.Option.default = function (self) end;         -- When the player clicks default and these settings, run this function.

		InterfaceOptions_AddCategory(Addon.Option);

		----------------------------------------------------------------------------------
		print ( " - " .. Title .. " " .. Version .. " Plugin Loaded ..." )
		-- UNREGISTER EVENT
		EventFrame : UnregisterEvent("ADDON_LOADED")
	end
	-------------------------------------------------------------------------------------------
	-- EVENT PLAYER_LOGIN ----------------------------------------------------------------
	-------------------------------------------------------------------------------------------
	function EventFrame : PLAYER_LOGIN ()
		
		if SettingsDB.HideGryphons.Enbled == true 
			then 
				Addon.Option.CheckButton:SetChecked(SettingsDB.HideGryphons.Enbled)
				HideGryphons()
			else
				Addon.Option.CheckButton:SetChecked(SettingsDB.HideGryphons.Enbled)
				ShowGryphons()
		end

	end
	-------------------------------------------------------------------------------------------
	-- EVENT PLAYER_LOGOUT ----------------------------------------------------------------
	-------------------------------------------------------------------------------------------
	function EventFrame : PLAYER_LOGOUT ()

	end	

	-------------------------------------------------------------------------------------------
        -- REGISTER EVENTS ------------------------------------------------------------------------
        -------------------------------------------------------------------------------------------
	EventFrame : RegisterEvent ( "ADDON_LOADED" );
	EventFrame : RegisterEvent ( "PLAYER_LOGIN" );
	EventFrame : RegisterEvent ( "PLAYER_LOGOUT" );
	-------------------------------------------------------------------------------------------
	EventFrame : SetScript ( "OnEvent" , function ( self , event , ... ) if self[event] then return self[event]( self , event , ... ) end end )

	local	function AddonSlashCommand ( msg , var )
			
		local _, _, command, subcommand = string.find(msg, "%s?(%w+)%s?(.*)")
		
		if	command == "show" then   
			_G.NewAddonPrefs = Addon.DefaultDatabase
			Addon.Reset = true
			ShowGryphons()
			print("Show Gryphons on Actionbar.")
			
		elseif	command == "hide" then
			HideGryphons()
			print("Hide Gryphons from Actionbar.")

		else	-- If not handled above, display some sort of help message
			print ( " |cffff0033=======================================|r" )
			print ( " |cffffcc00Hide Gryphons Plugin |r" .. Version .. "|cff0066ff Slash Command Help|r" )
			print ( " |cffff0033=======================================|r" )
	--		print("Syntax: ");
			local msgList = {
			    { "Show"	, "Show Gryphons " },
			    { "Hide"	, "Hide Gryphons  " },

			}

		    for i=1, #msgList do
			-- print("/ex |cffffe132".. msgList[i][1] ..  "|r " .. msgList[i][2] )
			print("   - " .. msgList[i][2] .. "|cffffcc00Syntax: |r/dh |cff99ff99".. msgList[i][1] ..  "|r " )
		    end
				InterfaceOptionsFrame_OpenToCategory(Addon.Option) 
				InterfaceOptionsFrame_OpenToCategory(Addon.Option.name) 

		end
	end

		SLASH_D_GRYPHON1 = '/dh'
		SlashCmdList["D_GRYPHON"] = AddonSlashCommand    -- add /dh to command list